/*
 * Copyright (C) 2009, 2010 Hermann Meyer, James Warden, Andreas Degert
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef __GXWMM_H__
#define __GXWMM_H__

#include <gxwmm/bigknob.h>
#include <gxwmm/controlparameter.h>
#include <gxwmm/eqslider.h>
#include <gxwmm/fastmeter.h>
#include <gxwmm/levelslider.h>
#include <gxwmm/hslider.h>
#include <gxwmm/iredit.h>
#include <gxwmm/knob.h>
#include <gxwmm/meterscale.h>
#include <gxwmm/midknob.h>
#include <gxwmm/minislider.h>
#include <gxwmm/paintbox.h>
#include <gxwmm/radiobutton.h>
#include <gxwmm/regler.h>
#include <gxwmm/selector.h>
#include <gxwmm/smallknob.h>
#include <gxwmm/smallknobr.h>
#include <gxwmm/simplevaluedisplay.h>
#include <gxwmm/switch.h>
#include <gxwmm/toggleimage.h>
#include <gxwmm/tuner.h>
#include <gxwmm/racktuner.h>
#include <gxwmm/vslider.h>
#include <gxwmm/valuedisplay.h>
#include <gxwmm/waveview.h>
#include <gxwmm/wheel.h>
#include <gxwmm/portdisplay.h>
#include <gxwmm/playhead.h>
#include <gxwmm/init.h>

#endif /* __GXWMM_H__ */
